* The analyses were performed using Stata 16.1
*==========================================================
* set up
*==========================================================
clear
set more off
macro drop _all
set scheme lean2 // plotplain s2mono s1color s1mono lean1

cap cd "F:/OneDrive - Cornell University/DemRes/"
global data = "$pwd" + "data"
global results = "$pwd" + "results"

*==========================================================
* start logging
*==========================================================
log close _all
log using "$results/figures.log", replace

*==========================================================
* figure_1
*==========================================================
** publications from CliMig: N = 1412
insheet using "$data/Fig_PubTrend_CliMig_Final.csv", clear
tempfile climig_final
save `climig_final'

** publications from other 7 meta-analysis: included (60) + excluded (26) = 86
use "$data/Fig_PubTrend_OtherMeta.dta", clear
rename pub_yr year
append using `climig_final'
gen paper_id = _n
order paper_id year status
keep paper_id year

** prepare data for plotting
collapse (count) paper_id, by(year)
rename paper_id pubs
label var year "Year"
label var pubs "Total publications"

gen year1 = 1 if year == 2011 | year == 2018
replace year1 = 2 if year == 2014 | year == 2017

gen pubs2 = pubs
replace pubs2 = 122 if year == 2020

** plot
twoway (line pubs year) || (line pubs2 year), ///
    xlabel(1945(5)2005 2011 2014 2017 2018 2020, labsize(small) angle(90)) || ///
    scatter pubs year if year1 == 1, ms(none) mlabel(pubs) mlabpos(12) || ///
    scatter pubs year if year1 == 2, ms(none) mlabel(pubs) mlabpos(6) ///
    legend(pos(7) ring(0)) || ///
    scatter pubs2 year if year == 2020, ms(none) mlabel(pubs2) mlabpos(12) || ///
    scatter pubs year if year == 2020, ms(none) mlabel(pubs) mlabpos(6)
gr_edit legend.plotregion1.key[3].draw_view.setstyle, style(no)
gr_edit legend.plotregion1.key[4].draw_view.setstyle, style(no)
gr_edit legend.plotregion1.key[5].draw_view.setstyle, style(no)
gr_edit legend.plotregion1.key[6].draw_view.setstyle, style(no)
gr_edit legend.plotregion1.label[3].draw_view.setstyle, style(no)
gr_edit legend.plotregion1.label[4].draw_view.setstyle, style(no)
gr_edit legend.plotregion1.label[5].draw_view.setstyle, style(no)
gr_edit legend.plotregion1.label[6].draw_view.setstyle, style(no)
gr_edit legend.DragBy 2.729796975188738 0
gr_edit legend.plotregion1.label[1].text = {}
gr_edit legend.plotregion1.label[1].text.Arrpush Collected publications from CliMig
gr_edit legend.plotregion1.label[2].text = {}
gr_edit legend.plotregion1.label[2].text.Arrpush Total publications from Web of Science in 2020
gr_edit legend.style.editstyle boxstyle(shadestyle(color(none)))
gr_edit legend.style.editstyle boxstyle(linestyle(color(none)))
graph export "$results/figure_1.png", width(1200) height(800) replace

*==========================================================
* figure_3
*==========================================================
use "$data/EnvMig.dta", clear
meta set pcc pcc_se
meta funnelplot, title("") contours(1 5 10) ///
    xtitle("Partial correlation coefficient (PCC)") ytitle("Standard error") ///
    ylabel(0.23 0.2 0.15 0.1 0.05 0.00) ///
    legend(row(5) position(5) ring(0) size(vsmall) region(lstyle(none))) ///
    name(f1, replace) scheme(plotplain) ///
    play("$data/figure_3_mode")
graph export "$results/figure_3.png", width(1200) height(800) replace

*==========================================================
* end logging
*==========================================================
// clear
log close _all

// *==========================================================
// * clear memory and exit
// *==========================================================
// exit, clear STATA

*=========================== END ===========================

