* The analyses were performed using Stata 16.1
*==========================================================
* set up
*==========================================================
clear
set more off
macro drop _all
set scheme lean2 // plotplain s2mono s1color s1mono lean1

cap cd "F:/OneDrive - Cornell University/DemRes/"
global data = "$pwd" + "data"
global results = "$pwd" + "results"

*==========================================================
* start logging
*==========================================================
log close _all
log using "$results/tables.log", replace

*==========================================================
* table_3
*==========================================================
use "$data/EnvMig.dta", clear
gen envcat = env_cat
replace envcat = 7 if env_cat == 2 | env_cat == 3 // combine flood and drought into precipitation
label define envcat 1 "disaster" 4 "land" 5 "loss" 6 "other" 7 "precipitation" 8 "temperature"
label values envcat envcat
sum pcc pcc_se
foreach v of varlist intl migtype envcat env_rapid country_type controls datacent_1970_2010 {
    tab `v', mi
}

*==========================================================
* table_4
*==========================================================
use "$data/EnvMig.dta", clear

** out-migration
preserve
keep if migtype == 3
des, s
tab psig, mi
tab coef_direct if psig == 1
restore

** in-migration
preserve
keep if migtype == 1
des, s
tab psig, mi
tab coef_direct if psig == 1
restore

** net-migration
preserve
keep if migtype == 2
des, s
tab psig, mi
tab coef_direct if psig == 1
restore

*==========================================================
* table_5
*==========================================================
** combine flood and drought into precipitation
use "$data/EnvMig.dta", clear
gen envcat = env_cat
replace envcat = 7 if env_cat == 2 | env_cat == 3 // combine flood and drought into precipitation
label define envcat 1 "disaster" 4 "land" 5 "loss" 6 "other" 7 "precipitation" 8 "temperature"
label values envcat envcat

** weighted average PCC
tab migtype, mi
mean pcc [pweight=weight_prec] if migtype == 1 // in-migration
mean pcc [pweight=weight_prec] if migtype == 2 // net-migration
mean pcc [pweight=weight_prec] if migtype == 3 // out-migration

tab envcat if migtype == 1, mi
mean pcc [pweight=weight_prec] if migtype == 1, over(envcat) // in-migration
tab envcat if migtype == 2, mi
mean pcc [pweight=weight_prec] if migtype == 2, over(envcat) // net-migration
tab envcat if migtype == 3, mi
mean pcc [pweight=weight_prec] if migtype == 3, over(envcat) // out-migration

tab env_rapid if migtype == 1, mi
mean pcc [pweight=weight_prec] if migtype == 1, over(env_rapid) // in-migration
tab env_rapid if migtype == 2, mi
mean pcc [pweight=weight_prec] if migtype == 2, over(env_rapid) // net-migration
tab env_rapid if migtype == 3, mi
mean pcc [pweight=weight_prec] if migtype == 3, over(env_rapid) // out-migration

*==========================================================
* table_6
*==========================================================
**===============================================
** out-migration using OLS and IV
**===============================================
*** combine flood and drought into precipitation
use "$data/EnvMig.dta", clear
gen envcat = env_cat
replace envcat = 7 if env_cat == 2 | env_cat == 3 // combine flood and drought into precipitation
label define envcat 1 "disaster" 4 "land" 5 "loss" 6 "other" 7 "precipitation" 8 "temperature"
label values envcat envcat

*** macro variables
local controls "i.intl ib2.country_type i.controls i.datayr_1980s i.datayr_1990s i.datayr_2000s i.datayr_2010s"

keep if migtype == 3
tab country_type, gen(countrytype_)
tab env_general, gen(env_general_)

*** typology
reg pcc ib6.envcat `controls' pcc_se, cluster (country) robust
estat ic
matrix ics = r(S)
local aic = ics[1, 5]
local bic = ics[1, 6]
outreg2 using "$results/table_6.doc", replace label stats(coef se) ctitle("OLS") ///
    dec(2) alpha(0.001, 0.01, 0.05, 0.10) symbol(***, **, *, +) addstat(AIC, `aic', BIC, `bic')

ivregress 2sls pcc ib6.envcat `controls' (pcc_se = instrument) [pweight = weight_prec], cluster (country) robust
outreg2 using "$results/table_6.doc", append label stats(coef se) ctitle("IV") ///
    dec(2) alpha(0.001, 0.01, 0.05, 0.10) symbol(***, **, *, +)

*** velocity
reg pcc i.env_rapid `controls' pcc_se, cluster (country) robust
estat ic
matrix ics = r(S)
local aic = ics[1, 5]
local bic = ics[1, 6]
outreg2 using "$results/table_6.doc", append label stats(coef se) ctitle("OLS") ///
    dec(2) alpha(0.001, 0.01, 0.05, 0.10) symbol(***, **, *, +) addstat(AIC, `aic', BIC, `bic')

ivregress 2sls pcc i.env_rapid `controls' (pcc_se = instrument) [pweight = weight_prec], cluster (country) robust
outreg2 using "$results/table_6.doc", append label stats(coef se) ctitle("IV") ///
    dec(2) alpha(0.001, 0.01, 0.05, 0.10) symbol(***, **, *, +)

**===============================================
** net migration using OLS and IV
**===============================================
*** combine flood and drought into precipitation
use "$data/EnvMig.dta", clear
gen envcat = env_cat
replace envcat = 7 if env_cat == 2 | env_cat == 3 // combine flood and drought into precipitation
label define envcat 1 "disaster" 4 "land" 5 "loss" 6 "other" 7 "precipitation" 8 "temperature"
label values envcat envcat

*** macro variables
local controls "i.intl ib2.country_type i.controls i.datayr_1980s i.datayr_1990s i.datayr_2000s i.datayr_2010s"

keep if migtype == 2
tab country_type, gen(countrytype_)
tab env_general, gen(env_general_)

*** typology
reg pcc ib6.envcat `controls' pcc_se, cluster (country) robust
estat ic
matrix ics = r(S)
local aic = ics[1, 5]
local bic = ics[1, 6]
outreg2 using "$results/table_6.doc", append label stats(coef se) ctitle("OLS") ///
    dec(2) alpha(0.001, 0.01, 0.05, 0.10) symbol(***, **, *, +) addstat(AIC, `aic', BIC, `bic')

ivregress 2sls pcc ib6.envcat `controls' (pcc_se = instrument) [pweight = weight_prec], cluster (country) robust
outreg2 using "$results/table_6.doc", append label stats(coef se) ctitle("IV") ///
    dec(2) alpha(0.001, 0.01, 0.05, 0.10) symbol(***, **, *, +)

*** velocity
reg pcc i.env_rapid `controls' pcc_se, cluster (country) robust
estat ic
matrix ics = r(S)
local aic = ics[1, 5]
local bic = ics[1, 6]
outreg2 using "$results/table_6.doc", append label stats(coef se) ctitle("OLS") ///
    dec(2) alpha(0.001, 0.01, 0.05, 0.10) symbol(***, **, *, +) addstat(AIC, `aic', BIC, `bic')

ivregress 2sls pcc i.env_rapid `controls' (pcc_se = instrument) [pweight = weight_prec], cluster (country) robust
outreg2 using "$results/table_6.doc", append label stats(coef se) ctitle("IV") ///
    dec(2) alpha(0.001, 0.01, 0.05, 0.10) symbol(***, **, *, +)

*==========================================================
* table_a2
*==========================================================
** combine flood and drought into precipitation
use "$data/EnvMig.dta", clear
gen envcat = env_cat
replace envcat = 7 if env_cat == 2 | env_cat == 3 // combine flood and drought into precipitation
label define envcat 1 "disaster" 4 "land" 5 "loss" 6 "other" 7 "precipitation" 8 "temperature"
label values envcat envcat

keep if migtype == 2 | migtype == 1 // n = 907
tab country_type, gen(countrytype_)
tab env_general, gen(env_general_)

** typology
reg pcc ib6.envcat `controls' pcc_se, cluster (country) robust
estat ic
matrix ics = r(S)
local aic = ics[1, 5]
local bic = ics[1, 6]
outreg2 using "$results/table_a2.doc", replace label stats(coef se) ctitle("OLS") ///
    dec(2) alpha(0.001, 0.01, 0.05, 0.10) symbol(***, **, *, +) addstat(AIC, `aic', BIC, `bic')

ivregress 2sls pcc ib6.envcat `controls' (pcc_se = instrument) [pweight = weight_prec], cluster (country) robust
outreg2 using "$results/table_a2.doc", append label stats(coef se) ctitle("IV") ///
    dec(2) alpha(0.001, 0.01, 0.05, 0.10) symbol(***, **, *, +)

** velocity
reg pcc i.env_rapid `controls' pcc_se, cluster (country) robust
estat ic
matrix ics = r(S)
local aic = ics[1, 5]
local bic = ics[1, 6]
outreg2 using "$results/table_a2.doc", append label stats(coef se) ctitle("OLS") ///
    dec(2) alpha(0.001, 0.01, 0.05, 0.10) symbol(***, **, *, +) addstat(AIC, `aic', BIC, `bic')

ivregress 2sls pcc i.env_rapid `controls' (pcc_se = instrument) [pweight = weight_prec], cluster (country) robust
outreg2 using "$results/table_a2.doc", append label stats(coef se) ctitle("IV") ///
    dec(2) alpha(0.001, 0.01, 0.05, 0.10) symbol(***, **, *, +)

*==========================================================
* table_a3
*==========================================================
**===============================================
** out-migration using multilevel model
**===============================================
*** typology
use "$data/EnvMig.dta", clear
keep if migtype == 3
tab country_type, gen(countrytype_)
tab env_general, gen(env_general_)
gen envcat = env_cat
replace envcat = 7 if env_cat == 2 | env_cat == 3
label define envcat 1 "disaster" 4 "land" 5 "loss" 6 "other" 7 "precipitation" 8 "temperature"
label values envcat envcat

***mlm
meglm pcc ib6.envcat `controls' pcc_se || pid_str:,
estat icc
estat ic
matrix ics = r(S)
local aic = ics[1, 5]
local bic = ics[1, 6]
outreg2 using "$results/table_a3.doc", replace label stats(coef se) ctitle("Out migration") ///
    dec(2) alpha(0.001, 0.01, 0.05, 0.10) symbol(***, **, *, +) addstat(AIC, `aic', BIC, `bic')

*** velocity
use "$data/EnvMig.dta", clear
keep if migtype == 3
tab country_type, gen(countrytype_)
tab env_general, gen(env_general_)

*** mlm
meglm pcc i.env_rapid `controls' pcc_se || pid_str:,
estat icc
estat ic
matrix ics = r(S)
local aic = ics[1, 5]
local bic = ics[1, 6]
outreg2 using "$results/table_a3.doc", append label stats(coef se) ctitle("Out migration") ///
    dec(2) alpha(0.001, 0.01, 0.05, 0.10) symbol(***, **, *, +) addstat(AIC, `aic', BIC, `bic')

**===============================================
** net migration using multilevel model
**===============================================
*** typology
use "$data/EnvMig.dta", clear
keep if migtype == 2
tab country_type, gen(countrytype_)
tab env_general, gen(env_general_)
gen envcat = env_cat
replace envcat = 7 if env_cat == 2 | env_cat == 3
label define envcat 1 "disaster" 4 "land" 5 "loss" 6 "other" 7 "precipitation" 8 "temperature"
label values envcat envcat

*** mlm
meglm pcc ib6.envcat `controls' pcc_se || pid_str:,
estat icc
estat ic
matrix ics = r(S)
local aic = ics[1, 5]
local bic = ics[1, 6]
outreg2 using "$results/table_a3.doc", append label stats(coef se) ctitle("Net migration") ///
    dec(2) alpha(0.001, 0.01, 0.05, 0.10) symbol(***, **, *, +) addstat(AIC, `aic', BIC, `bic')

*** velocity
use "$data/EnvMig.dta", clear
keep if migtype == 2
tab country_type, gen(countrytype_)
tab env_general, gen(env_general_)

*** mlm
meglm pcc i.env_rapid `controls' pcc_se || pid_str:,
estat icc
estat ic
matrix ics = r(S)
local aic = ics[1, 5]
local bic = ics[1, 6]
outreg2 using "$results/table_a3.doc", append label stats(coef se) ctitle("Net migration") ///
    dec(2) alpha(0.001, 0.01, 0.05, 0.10) symbol(***, **, *, +) addstat(AIC, `aic', BIC, `bic')

*==========================================================
* end logging
*==========================================================
// clear
log close _all

*==========================================================
* erase txt
*==========================================================
cd "$results"
local txts: dir . files "*.txt"
foreach txt of local txts {
    erase `txt'
}

// *==========================================================
// * clear memory and exit
// *==========================================================
// exit, clear STATA

*=========================== END ===========================

